# shine.validation.statistics

Statistical analysis for bias measurement.

Computes multiplicative and additive shear bias, coverage tests,
and simulation-based calibration (SBC) diagnostics.

::: shine.validation.statistics
